from datetime import datetime
import random

# Define the alphanumeric characters
_alphnum = [chr(i) for i in range(48, 58)] + [chr(i) for i in range(65, 91)] + [chr(i) for i in range(97, 123)]

def get_easyb2b_reference(code_len: int = 16) -> str:
    """
    Generate a unique reference code for a transaction by combining the current date-time string and a random alphanumeric code.
    
    Args:
        code_len (int, optional): The length of the random alphanumeric code. Default is 16.

    Returns:
        str: The generated reference code.
    """
    date_str = datetime.now().strftime("%Y%m%d%I%M")
    random_code = ''.join(random.sample(_alphnum, code_len))    
    return f"{date_str}{random_code}"





import requests
import os
from . import exceptions
from .mocked import MockedRequests

API_KEY = os.getenv('EASYMOBILE_API_KEY')

class EasyBase:
    """
    A class to interact with the EasyB2B API.
    
    Attributes:
        api_key (str): The API key for authentication.
        timeout (float): The timeout for API requests.
    """
    _mocked = False
    sess = None
    base_url = "https://b2b.eazymobile.ng/api/live"
    timeout = 45.1

    def __init__(self, api_key: str = None, timeout: float = None) -> None:
        """
        Initialize the EasyB2B object.
        """
        if timeout:
            self.timeout = timeout

        self.req_session = requests.session()
        self.req_session.headers['Content-Type'] = 'application/json'
        self.req_session.headers['Accept'] = 'application/json'

        if api_key:
            self.req_session.headers['Authorization'] = f'Bearer {api_key}'
            self.mocked = True if api_key.lower() == 'demo' else False
        elif API_KEY:
            self.req_session.headers['Authorization'] =  f'Bearer {API_KEY}'
            self.mocked = True if API_KEY.lower() == 'demo' else False
        else:
            raise ValueError("Invalid or No API key provided!")

    @property
    def mocked(self):
        return self._mocked

    @mocked.setter
    def mocked(self, val):
        if not isinstance(val, bool):
            raise ValueError("property mocked must be a boolean value!")
        if val:
            self.sess = MockedRequests(session=self.req_session)
        else:
            self.sess = self.req_session
        self._mocked = val

    def get_wallet_balance(self, email, **kwargs):
        """
        Get the wallet balance for a given email.

        Args:
            email (str): The email to get the wallet balance for.

        Returns:
            dict: The response from the API as a JSON dictionary.
        """
        url = f'{self.base_url}/v1/load/wallet-balance'
        data = {'email': email}
        data.update(**kwargs)
        try:
            response = self.sess.post(url, json=data, timeout=self.timeout)
            response.raise_for_status()
            return response.json()
        except exceptions.RequestException as e:
            return {'error': str(e)}

    def get_transaction_status(self, name: str, ref: str):
        """
        Get the transaction status for a given transaction reference.

        Args:
            name (str): The name/type associated with the transaction.
            ref (str): The reference of the transaction.

        Returns:
            dict: The response from the API as a JSON dictionary.
        """
        url = f'{self.base_url}/v1/transaction/status/{name}'
        data = {"reference": ref}
        try:
            response = self.sess.post(url, json=data, timeout=self.timeout)
            response.raise_for_status()
            return response.json()
        except exceptions.RequestException as e:
            return {'error': str(e)}



from . import exceptions
from .base import EasyBase


class EasyData(EasyBase):
    """
    A class to interact with the EasyB2B API for data-related operations.
    ref: https://b2b.eazymobile.ng/api/developer/v1/documentation/start#item-2-3
    """
    
    def __init__(self, api_key:str=None, timeout=None) -> None:
        """
        Initialize the EasyData object.
        
        Args:
            api_key (str, optional): The API key for authentication. If not provided, will use the environment variable `EASYB2B_API_KEY`. Set key as "Demo" to use the mocked API..
            timeout (float, optional): Timeout for the requests. Default is 45.1 seconds.
        """
        super().__init__(api_key, timeout)

    def get_networks(self, networks='all', **kwargs):
        """
        Retrieve available networks for data top-up.

        Args:
            networks (str, optional): Specify the network to retrieve. Default is 'all'. Do not change unless you know what you are doing!
            **kwargs: Additional keyword arguments.

        Returns:
            dict: JSON response from the API.
        """
        url = f'{self.base_url}/v1/topup/load/networks'
        data = {'networks': networks}
        data.update(**kwargs)
        try:
            response = self.sess.post(url, json=data, timeout=self.timeout)
            response.raise_for_status()
            return response.json()
        except exceptions.RequestException as e:
            return {'error': str(e)}


    def get_data_types(self, network:int, **kwargs):
        """
        Retrieve available data types for a specific network.

        Args:
            network (int): Network ID. Use the `.get_networks` method to fetch available networks and their IDs.
            **kwargs: Additional keyword arguments.

        Returns:
            dict: JSON response from the API.
        """
        url = f'{self.base_url}/v1/topup/load/data-types'
        data = {'network': str(network)}
        data.update(**kwargs)
        try:
            response = self.sess.post(url, json=data, timeout=self.timeout)
            response.raise_for_status()
            return response.json()
        except exceptions.RequestException as e:
            return {'error': str(e)}


    def get_data_plans(self, network:int, data_type:str, **kwargs):
        """
        Retrieve data plans for a specific network and data type.

        Args:
            network (int): Network ID. Use the `.get_networks` method to fetch available networks and their IDs.
            data_type (str): Type of data. Use the `.get_data_types` method to fetch available data types.
            **kwargs: Additional keyword arguments.

        Returns:
            dict: JSON response from the API.
        """
        url = f'{self.base_url}/v1/topup/load/data'
        data = {'network': str(network), 'dataType': data_type}
        data.update(**kwargs)
        try:
            response = self.sess.post(url, json=data, timeout=self.timeout)
            response.raise_for_status()
            return response.json()
        except exceptions.RequestException as e:
            return {'error': str(e)}


    def purchase_data(self, reference:str, network:int, data_type:str, plan_id:str, phone:str):
        """
        Purchase data for a given phone number.

        Args:
            reference (str): Unique reference for the transaction. (see https://b2b.eazymobile.ng/api/developer/v1/documentation/start#item-2-14 ).
            network (int): Network ID. Default is 1. Use the `.get_networks` method to fetch available networks and their IDs.
            data_type (str): Type of data. Use the `.get_data_types` method to fetch available data types.
            plan_id (str): ID of the data plan. Use the `.get_data_plans` method to fetch available data plans.
            phone (str): Phone number to receive the data.

        Returns:
            dict: JSON response from the API.
        """
        url = f'{self.base_url}/v1/topup/data'
        data = {
            "network": str(network),
            "dataType": data_type,
            "planId": str(plan_id),
            "phone": phone,
            "reference": reference 
        }
        try:
            response = self.sess.post(url, json=data, timeout=self.timeout)
            response.raise_for_status()
            return response.json()
        except exceptions.RequestException as e:
            return {'error': str(e)}


    def get_transaction_status(self, ref: str):
        """
        Get the status of a specific data transaction.

        Args:
            ref (str): Reference of the transaction.

        Returns:
            dict: JSON response from the API.
        """
        return super().get_transaction_status('data', ref)


if __name__ == "__main__":
    pass



from .base import EasyBase


class EasyCable(EasyBase):
    """
    A class to interact with the EasyB2B API for cable TV-related operations.
    ref: https://b2b.eazymobile.ng/api/developer/v1/documentation/start#item-2-5
    """
    
    def __init__(self, api_key: str = None, timeout=None) -> None:
        """
        Initialize the EasyCable object.
        
        Args:
            api_key (str, optional): The API key for authentication. If not provided, will use the environment variable `EASYB2B_API_KEY`. Set key as "Demo" to use the mocked API.
            timeout (float, optional): Timeout for API requests.
        """
        super().__init__(api_key, timeout)

    def get_cables(self, cable='all', **kwargs):
        """
        Retrieve available cable types.

        Args:
            cable (str, optional): Specify the cable type to retrieve. Default is 'all'. Do not change unless you know what you are doing!
            **kwargs: Additional keyword arguments.

        Returns:
            dict: JSON response from the API.
        """
        url = f'{self.base_url}/v1/topup/load/cable-types'
        data = {'cables': cable}
        data.update(**kwargs)
        response = self.sess.post(url, json=data, timeout=self.timeout)
        return response.json()

    def get_cable_packages(self, cable_id:int, **kwargs):
        """
        Retrieve available packages for a specific cable type.

        Args:
            cable_id (int): Cable ID. Use the `.get_cables` method to fetch available cables and their IDs.
            **kwargs: Additional keyword arguments.

        Returns:
            dict: JSON response from the API.
        """
        url = f'{self.base_url}/v1/topup/load/cable-packages'
        data = {'cableId': str(cable_id)}
        data.update(**kwargs)
        response = self.sess.post(url, json=data, timeout=self.timeout)
        return response.json()

    def validate_smartcard_iuc_number(self, cable_id:int, smartcard_no:str, **kwargs):
        """
        Validate the smartcard/IUC number for a cable service.

        Args:
            cable_id (int): Cable ID. Use the `.get_cables` method to fetch available cables and their IDs.
            smartcard_no (str): Smartcard/IUC number to validate.
            **kwargs: Additional keyword arguments.

        Returns:
            dict: JSON response from the API.
        """
        url = f'{self.base_url}/v1/topup/validate/smartcard-no'
        data = {'cableId': str(cable_id), 'smartCardNo': smartcard_no}
        data.update(**kwargs)
        response = self.sess.post(url, json=data, timeout=self.timeout)
        return response.json()

    def purchase_cable(self, reference:str, cable_id:str, package_id:str, smartcard_no:str, amount_optional:str=None):
        """
        Purchase a cable package for a given smartcard/IUC number.

        Args:
            reference (str): Unique reference for the transaction.
            cable_id (str): Cable ID. Default is '1'.
            package_id (str): Package ID. Default is '1'.
            smartcard_no (str): Smartcard/IUC number.
            amount_optional (str, optional): Optional amount for top-up.

        Returns:
            dict: JSON response from the API.
        """
        url = f'{self.base_url}/v1/topup/cable'
        data = {
            "cableId": str(cable_id),
            "packageId": str(package_id),
            "smartCardNo": smartcard_no,
            "reference": reference 
        }
        if amount_optional is not None:
            data["topupAmount"] = amount_optional
        response = self.sess.post(url, json=data, timeout=self.timeout)
        return response.json()

    def get_transaction_status(self, ref: str):
        """
        Get the status of a specific cable transaction.

        Args:
            ref (str): Reference of the transaction.

        Returns:
            dict: JSON response from the API.
        """
        return super().get_transaction_status('cable', ref)


if __name__ == "__main__":
    pass




class MockedRequests:
    """
    A class to mock API responses for testing purposes.
    
    Attributes:
        session (requests.Session): The session with pre-configured headers.
    """
    base_url = "https://b2b.eazymobile.ng/api"
    urls = [
        # Airtime and Data
        (f'{base_url}/live/v1/load/wallet-balance', f"{base_url}/test/v1/load/wallet-balance", {"status": True, "code": 200, "data": {"product": {"wallet": "82318.60"}}}),
        (f'{base_url}/live/v1/topup/load/networks', f'{base_url}/test/v1/topup/load/networks', {'status': True, 'code': 200, 'data': {'product': [{'network': 'MTN', 'networkId': 1}, {'network': 'AIRTEL', 'networkId': 2}, {'network': 'GLO', 'networkId': 3}, {'network': '9MOBILE', 'networkId': 4}]}}),
        (f'{base_url}/live/v1/topup/load/airtime-types', f'{base_url}/test/v1/topup/load/airtime-types', {'status': True, 'code': 200, 'data': {'product': [{'network': 'MTN', 'networkId': 1, 'name': 'VTU'}, {'network': 'MTN', 'networkId': 1, 'name': 'SNS'}, {'network': 'MTN', 'networkId': 1, 'name': 'AWOOF4U'}, {'network': 'MTN', 'networkId': 1, 'name': 'GARABASA'}]}}),
        (f'{base_url}/live/v1/topup/load/data-types', f'{base_url}/test/v1/topup/load/data-types', {'status': True, 'code': 200, 'data': {'product': [{'network': 'MTN', 'networkId': 1, 'name': 'SME'}, {'network': 'MTN', 'networkId': 1, 'name': 'CORPORATE GIFTING'}, {'network': 'MTN', 'networkId': 1, 'name': 'DIRECT GIFTING'}, {'network': 'MTN', 'networkId': 1, 'name': 'NORMAL GIFTING'}]}}),
        (f'{base_url}/live/v1/topup/load/airtime-rate', f'{base_url}/test/v1/topup/load/airtime-rate', {'status': True, 'code': 200, 'data': {'product': {'rate': '97%'}}}),
        (f'{base_url}/live/v1/topup/load/data', f'{base_url}/test/v1/topup/load/data', {'status': True, 'code': 200, 'data': {'product': [{'network': 'MTN', 'planName': '500MB [SME] - 30 DAYS', 'planId': '1', 'price': '140', 'status': 'AVAILABLE'}, {'network': 'MTN', 'planName': '1GB [SME] - 30 DAYS', 'planId': '2', 'price': '240', 'status': 'AVAILABLE'}, {'network': 'MTN', 'planName': '2GB [SME] - 30 DAYS', 'planId': '3', 'price': '480', 'status': 'AVAILABLE'}, {'network': 'MTN', 'planName': '3GB [SME] - 30 DAYS', 'planId': '4', 'price': '720', 'status': 'AVAILABLE'}, {'network': 'MTN', 'planName': '5GB [SME] - 30 DAYS', 'planId': '5', 'price': '1200', 'status': 'AVAILABLE'}, {'network': 'MTN', 'planName': '10GB [SME] - 30 DAYS', 'planId': '6', 'price': '2400', 'status': 'AVAILABLE'}]}}),
        (f"{base_url}/live/v1/topup/airtime", f"{base_url}/test/v1/topup/airtime", {'status': True, 'code': 200, 'data': {'message': 'SUCCESSFUL', 'reference': 'EZM20230811025911PIY3BD11'}, 'time': '2023-08-11 02:59:13'}),
        (f"{base_url}/live/v1/topup/data", f"{base_url}/test/v1/topup/data", {'status': True, 'code': 200, 'data': {'message': 'Dear Customer, You have successfully shared 500MB Data to 2348168639113. Your SME data balance is 26648.71GB expires 08/02/2024. Thankyou', 'reference': 'EZM20230311083236YLURDN36'}, 'time': '2023-03-11 08:32:39'}),

        # Cables
        (f"{base_url}/live/v1/topup/load/cable-types", f"{base_url}/test/v1/topup/load/cable-types", {"status": True, "code": 200, "data": {"product": [{"cable": "DSTV", "cableId": 1},{ "cable": "STARTIMES", "cableId": 2},{ "cable": "GOTV", "cableId": 3}]}}),
        (f"{base_url}/live/v1/topup/load/cable-packages", f"{base_url}/test/v1/topup/load/cable-packages", {"status": True, "code": 200, "data": {"product": [{"packageId": "1", "cable": "GOTV", "cableId": 3, "name": "GOTV SMALLIE", "price": "1100"}, { "packageId": "2", "cable": "GOTV", "cableId": 3, "name": "GOTV JINJA", "price": "2250"},]}}),
        (f"{base_url}/live/v1/topup/validate/smartcard-no", f"{base_url}/test/v1/topup/validate/smartcard-no", {"status": True,"code": 200,"data": {"validate": {"customerName": "A***DE DA****", "dueDate": "June 14th, 2023", "currentPackage": "GOTV JOLLI N2,800", "renewalAmount": 3280, "status": "SUSPENDED"}}}),
        (f"{base_url}/live/v1/topup/cable", f"{base_url}/test/v1/topup/cable", {"status": True, "code": 200, "data": {"message": "Success! Your cable purchase was successful!", "reference": "WPY20232806015819AUQQZ719" }, "time": "2023-28-06 01:58:21"}),
    ]

    def __init__(self, session=None) -> None:
        """
        Initialize the MockedRequests object.

        Args:
            session (requests.Session, optional): The session with pre-configured headers.
        """
        self.headers = session.headers if session else {}

    def post(self, url: str, data=None, json=None, **kwargs):
        """
        Mock the POST request to return predefined responses.

        Args:
            url (str): The URL for the POST request.
            data (dict, optional): The data to send in the body of the POST request.
            json (dict, optional): The JSON data to send in the body of the POST request.

        Returns:
            ResponseJson: The mocked response object.
        """
        if 'headers' in kwargs:
            self.headers.update(kwargs['headers'])
        
        # Assertions to ensure the request format is correct
        assert isinstance(json, dict), "The 'json' parameter must be a dictionary."
        assert 'Content-Type' in self.headers and self.headers['Content-Type'] == 'application/json'
        assert 'Accept' in self.headers and self.headers['Accept'] == 'application/json'
        assert 'Authorization' in self.headers and 'Bearer ' in self.headers['Authorization']

        # Find the matching URL and return the predefined response
        for live_url, test_url, response in self.urls:
            if url == live_url or url == test_url:
                return ResponseJson(response)
        
        return ResponseJson({"details": f"{url} not found!"}, status_code=404)

class ResponseJson:
    """
    A class to mock the response object.

    Attributes:
        json (dict): The JSON response data.
        status_code (int): The HTTP status code of the response.
    """
    
    def __init__(self, json: dict, status_code: int = 200) -> None:
        self.data = json
        self.status_code = status_code
    
    def json(self):
        """
        Return the JSON data of the response.

        Returns:
            dict: The JSON response data.
        """
        return self.data
    
    def raise_for_status(self):
        return



import unittest
from easymobile import EasyCable, get_easyb2b_reference

class TestEasyCable(unittest.TestCase):
    
    def setUp(self):
        self.easy_cable = EasyCable(api_key='demo')

    def test_get_cables(self):
        response = self.easy_cable.get_cables()
        self.assertTrue(response['status'])
        self.assertEqual(response['code'], 200)
        self.assertIn('product', response['data'])

    def test_get_cable_packages(self):
        response = self.easy_cable.get_cable_packages(cable_id=3)
        self.assertTrue(response['status'])
        self.assertEqual(response['code'], 200)
        self.assertIn('product', response['data'])

    def test_validate_smartcard_iuc_number(self):
        response = self.easy_cable.validate_smartcard_iuc_number(cable_id=3, smartcard_no='1234567890')
        self.assertTrue(response['status'])
        self.assertEqual(response['code'], 200)
        self.assertIn('validate', response['data'])

    def test_purchase_cable(self):
        response = self.easy_cable.purchase_cable(reference=get_easyb2b_reference(), cable_id='3', package_id='1', smartcard_no='1234567890')
        self.assertTrue(response['status'])
        self.assertEqual(response['code'], 200)

    # def test_get_transaction_status(self):
    #     response = self.easy_cable.get_transaction_status(ref='test_ref')
    #     self.assertTrue(response['status'])
    #     self.assertEqual(response['data']['transaction'], 'completed')

if __name__ == "__main__":
    unittest.main()



import unittest
from easymobile import EasyData, get_easyb2b_reference

class TestEasyData(unittest.TestCase):
    
    def setUp(self):
        self.easy_data = EasyData(api_key='demo')

    def test_get_networks(self):
        response = self.easy_data.get_networks()
        self.assertTrue(response['status'])
        self.assertEqual(response['code'], 200)
        self.assertIn('product', response['data'])

    def test_get_data_types(self):
        response = self.easy_data.get_data_types(network=1)
        self.assertTrue(response['status'])
        self.assertEqual(response['code'], 200)
        self.assertIn('product', response['data'])

    def test_get_data_plans(self):
        response = self.easy_data.get_data_plans(network=1, data_type='SME')
        self.assertTrue(response['status'])
        self.assertEqual(response['code'], 200)
        self.assertIn('product', response['data'])

    def test_purchase_data(self):
        response = self.easy_data.purchase_data(reference=get_easyb2b_reference(), network=1, data_type='SME', plan_id='1', phone='08168639114')
        self.assertTrue(response['status'])
        self.assertEqual(response['code'], 200)

    # def test_get_transaction_status(self):
    #     response = self.easy_data.get_transaction_status(ref='test_ref')
    #     self.assertTrue(response['status'])
    #     self.assertEqual(response['data']['transaction'], 'completed')

if __name__ == "__main__":
    unittest.main()



import unittest
from unittest.mock import patch
from easymobile import EasyAirtime, get_easyb2b_reference

class TestMockedEasyAirtime(unittest.TestCase):
    
    def setUp(self):
        self.easy_airtime = EasyAirtime(api_key='demo')

    def test_get_networks(self):
        response = self.easy_airtime.get_networks()
        self.assertTrue(response['status'], response)
        self.assertEqual(response['code'], 200)
        self.assertIn('product', response['data'])

    def test_get_airtime_types(self):
        response = self.easy_airtime.get_airtime_types(network=1)
        self.assertTrue(response['status'])
        self.assertEqual(response['code'], 200)
        self.assertIn('product', response['data'])

    def test_get_airtime_rates(self):
        response = self.easy_airtime.get_airtime_rates(network=1, airtime_type='VTU')
        self.assertTrue(response['status'])
        self.assertEqual(response['code'], 200)
        # self.assertIn('rate', response['data']['product'])

    def test_purchase_airtime(self):
        response = self.easy_airtime.purchase_airtime(reference=get_easyb2b_reference(), network=1, airtime_type='SME', amount='10', phone='08168639114')
        self.assertTrue(response['status'])
        self.assertEqual(response['code'], 200)

    # def test_get_transaction_status(self):
    #     response = self.easy_airtime.get_transaction_status(ref=get_easyb2b_reference())
    #     print(response)
    #     self.assertTrue(response['status'], response)
        # self.assertEqual(response['data']['transaction'], 'completed')

if __name__ == "__main__":
    unittest.main()



from . import exceptions
from .base import EasyBase


class EasyAirtime(EasyBase):
    """
    A class to interact with the EasyB2B API for airtime-related operations.
    ref: https://b2b.eazymobile.ng/api/developer/v1/documentation/start#item-2-4
    """
    
    def __init__(self, api_key: str = None, timeout=None) -> None:
        """
        Initialize the EasyAirtime object.
        
        Args:
            api_key (str, optional): The API key for authentication. If not provided, will use the environment variable `EASYB2B_API_KEY`. Set key as "Demo" to use the mocked API.
            timeout (float, optional): Timeout for the requests. Default is 45.1 seconds.
        """
        super().__init__(api_key, timeout)

    def get_networks(self, networks:str='all', **kwargs):
        """
        Query all the networks for airtime top-up.

        Args:
            networks (str, optional): Specify the network to retrieve. Default is 'all'. Do not change unless you know what you are doing!
            **kwargs: Additional keyword arguments.

        Returns:
            dict: JSON response from the API.
        """
        url = f'{self.base_url}/v1/topup/load/networks'
        data = {'networks': networks}
        data.update(**kwargs)
        response = self.sess.post(url, json=data, timeout=self.timeout)
        try:
            response = self.sess.post(url, json=data, timeout=self.timeout)
            response.raise_for_status()
            return response.json()
        except exceptions.RequestException as e:
            return {'error': str(e)}

    def get_airtime_types(self, network:int, **kwargs):
        """
        Retrieve available airtime types for a specific network.

        Args:
            network (int): Network ID. Use the `.get_networks` method to fetch available networks and their IDs.
            **kwargs: Additional keyword arguments.

        Returns:
            dict: JSON response from the API.
        """
        url = f'{self.base_url}/v1/topup/load/airtime-types'
        data = {'network': str(network)}
        data.update(**kwargs)
        try:
            response = self.sess.post(url, json=data, timeout=self.timeout)
            response.raise_for_status()
            return response.json()
        except exceptions.RequestException as e:
            return {'error': str(e)}

    def get_airtime_rates(self, network:int, airtime_type:str, **kwargs):
        """
        Retrieve airtime rates for a specific network and airtime type.

        Args:
            network (int): Network ID. Use the `.get_networks` method to fetch available networks and their IDs.
            airtime_type (str): Type of airtime. Use the `.get_airtime_types` method to fetch available network types and their names.
            **kwargs: Additional keyword arguments.

        Returns:
            dict: JSON response from the API.
        """
        url = f'{self.base_url}/v1/topup/load/airtime-rate'
        data = {'network': str(network), 'airtimeType': airtime_type}
        data.update(**kwargs)
        try:
            response = self.sess.post(url, json=data, timeout=self.timeout)
            response.raise_for_status()
            return response.json()
        except exceptions.RequestException as e:
            return {'error': str(e)}

    def purchase_airtime(self, reference: str, network:int, airtime_type:str, amount:int, phone:str):
        """
        Purchase airtime for a given phone number.

        Args:
            reference (str): Unique reference for the transaction. (see https://b2b.eazymobile.ng/api/developer/v1/documentation/start#item-2-14 ).
            network (int): Network ID. Use the `.get_networks` method to fetch available networks and their IDs.
            airtime_type (str): Type of airtime. Use the `.get_airtime_types` method to fetch available network types and their names.
            amount (int|str): Amount of airtime to top-up.
            phone (str): Phone number to receive the airtime.

        Returns:
            dict: JSON response from the API.
        """
        url = f'{self.base_url}/v1/topup/airtime'
        data = {
            "network": str(network),
            "airtimeType": airtime_type,
            "amount": str(amount),
            "phone": phone,
            "reference": reference 
        }
        try:
            response = self.sess.post(url, json=data, timeout=self.timeout)
            response.raise_for_status()
            return response.json()
        except exceptions.RequestException as e:
            return {'error': str(e)}

    def get_transaction_status(self, ref: str):
        """
        Get the status of a specific airtime transaction.

        Args:
            ref (str): Reference of the transaction you generated and supplied.

        Returns:
            dict: JSON response from the API.
        """
        return super().get_transaction_status('airtime', ref)


if __name__ == "__main__":
    pass
